package com.supermap.samplecode.data;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.ListSelectionModel;
import javax.swing.SwingUtilities;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import com.supermap.data.Workspace;

/**
 * <p>
 * Title:工作空间管理
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明---------------------------- 
 * 此文件为SuperMap Objects Java 的示范代码
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：示范打开、另存、创建、删除文件型和数据库型工作空间 
 * 2、示例数据：无 
 * 3、关键类型/成员: 
 * Workspace.open 方法
 * Workspace.saveAs 方法 
 * Workspace.create 方法 
 * Workspace.deleteWorkspace 方法 
 * 4、使用步骤：
 * (1)点选打开工作空间页标签，打开示范数据工作空间
 * (2)点选另存工作空间页标签，将打开的工作空间存放的磁盘的其他位置
 * (3)可打开另存的工作空间文件查看
 * (4)点选删除工作空间页标签，将新另存的工作空间删除
 * (5)点选创建工作空间页标签，在磁盘的某位置新创建工作空间
 * (6)以上步骤同样适用于数据库型工作空间
 * ----------------------------------------------------------
 * --------------------
 * ============================================================================>
 * </p>
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * </p>
 * 
 */

/**
 * <p>
 * Title:Manage Workspace
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------Copyright Statement----------------------------
 * SuperMap Objects Java Sample Code 
 * Copyright: SuperMap Software Co., Ltd. All Rights Reserved.
 * ------------------------------------------------------------------------------
 *-----------------------Description--------------------------
 * 
 * 1、Sample Code Description：This sample demonstrates how to open, create, saveas or delete the workspace. 
 * 2、Sample Data Location:None
 * 3、Key Classes/Methods:
 * Workspace.open method
 * Workspace.saveAs method
 * Workspace.create method
 * Workspace.deleteWorkspace method 
 * 4、Procedures:
  * (1)Click the opening workspace label to open the demonstration workspace.
 * (2)Click the SaveAs workspace label to save the workspace as another workspace.
 * (3)Open the SaveAs workspace to view.
 * (4)Click the Delete label to delete the SaveAs workspace.
 * (5)Click the Create label to Create a new workspace.

 * ----------------------------------------------------------
 * --------------------
 * ============================================================================>
 * </p>
 * 
 * <p>
 * Company: SuperMap Software Co., Ltd.
 * </p>
 * 
 */

public class MainFrame extends JFrame {
	private static final long serialVersionUID = 1L;

	private JPanel m_contentPane;

	private JPanel m_panelToolBar;

	private Workspace m_workspace;

	private SampleRun m_sampleRun;

	private JTabbedPane m_tabbedPaneWorkspaceManage;

	private JTextArea m_textAreaWorkspaceInfo;

	private JScrollPane m_scrollPaneWorkspaceInfo;

	// 以下字段分别用于打开工作空间面板、另存工作空间面板、创建工作空间面板、删除工作空间面板
	// The following fields are used to open the workspace panel,save the workspace panel create the workspace panel and delete the workspace panel.
	private WorkspaceConnectionInfoPanel m_panelWorkspaceOpen;

	private WorkspaceConnectionInfoPanel m_panelWorkspaceSaveAs;

	private WorkspaceConnectionInfoPanel m_panelWorkspaceCreate;

	private WorkspaceConnectionInfoPanel m_panelWorkspaceDelete;

	private int m_selectedIndex;

	/**
	 * 程序入口点
	 * The entrance of the programme.
	 */
	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				MainFrame thisClass = new MainFrame();
				thisClass.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
				thisClass.setVisible(true);
			}
		});
	}

	/**
	 * 构造函数
	 * The constructor.
	 */
	public MainFrame() {
		super();
		initialize();
	}

	/**
	 * 初始化窗体
	 * Initialize the forms.
	 */
	private void initialize() {
		// 最大化显示窗体
		// Maximum the display form.
		this.setSize(600, 640);
		m_workspace = new Workspace();
		m_sampleRun = new SampleRun(m_workspace);
		this.setContentPane(getJContentPane());
		if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			this.setTitle("工作空间管理");
		}
		else
		{
			this.setTitle("Workspace Manage");
		}
		this.addWindowListener(new java.awt.event.WindowAdapter() {
			// 在窗体关闭时，需要释放相关的资源
			// Dispose resources when closing the form.
			public void windowClosing(java.awt.event.WindowEvent e) {
				m_workspace.dispose();
			}
		});
		try {
			Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
			Dimension frameSize = this.getSize();
			if (frameSize.height > screenSize.height) {
				frameSize.height = screenSize.height;
			}
			if (frameSize.width > screenSize.width) {
				frameSize.width = screenSize.width;
			}
			this.setLocation((screenSize.width - frameSize.width) / 2,
					(screenSize.height - frameSize.height) / 2);

		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}

	private JPanel getJContentPane() {
		if (m_contentPane == null) {
			m_contentPane = new JPanel();
			m_contentPane.setLayout(new BorderLayout());
			m_contentPane.add(getPanelToolBar(), BorderLayout.NORTH);
			m_contentPane
					.add(getScrollPaneWorkspaceInfo(), BorderLayout.CENTER);
			m_panelWorkspaceCreate.getListWorkspaceType().setSelectedIndex(0);
		}
		return m_contentPane;
	}

	/**
	 * 获取m_panelToolBar
	 * Get the m_panelToolBar.
	 */
	private JPanel getPanelToolBar() {
		if (m_panelToolBar == null) {
			m_panelToolBar = new JPanel();
			m_panelToolBar.setLayout(new BoxLayout(getPanelToolBar(),
					BoxLayout.X_AXIS));
			m_panelToolBar.add(getTabbedPaneWorkspaceManage(), null);
		}
		return m_panelToolBar;
	}

	/**
	 * 获取m_tabbedPaneWorkspaceManage
	 * Get the m_tabbedPaneWorkspaceManage.
	 */
	private JTabbedPane getTabbedPaneWorkspaceManage() {
		if (m_tabbedPaneWorkspaceManage == null) {
			m_tabbedPaneWorkspaceManage = new JTabbedPane();
			m_tabbedPaneWorkspaceManage.addTab(getText("m_tabbedPaneWorkspaceManage1"), null,
					getPanelWorkspaceOpen(), null);
			m_tabbedPaneWorkspaceManage.addTab(getText("m_tabbedPaneWorkspaceManage2"), null,
					getPanelWorkspaceSaveAs(), null);
			m_tabbedPaneWorkspaceManage.addTab(getText("m_tabbedPaneWorkspaceManage3"), null,
					getPanelWorkspaceCreate(), null);
			m_tabbedPaneWorkspaceManage.addTab(getText("m_tabbedPaneWorkspaceManage4"), null,
					getPanelWorkspaceDelete(), null);
			m_tabbedPaneWorkspaceManage.addChangeListener(new ChangeListener() {
				public void stateChanged(ChangeEvent e) {
					m_panelWorkspaceOpen.getListWorkspaceType()
							.setSelectedIndex(m_selectedIndex);
					m_panelWorkspaceCreate.getListWorkspaceType()
							.setSelectedIndex(m_selectedIndex);
					m_panelWorkspaceDelete.getListWorkspaceType()
							.setSelectedIndex(m_selectedIndex);
					m_panelWorkspaceSaveAs.getListWorkspaceType()
							.setSelectedIndex(m_selectedIndex);
				}
			});
			// 初始化页标签面板大小
			// Initialize the Label panel size.
			m_tabbedPaneWorkspaceManage.setSize(new Dimension(300, 150));

		}
		return m_tabbedPaneWorkspaceManage;
	}

	/**
	 * 获取m_scrollPaneWorkspaceInfo
	 * Get the m_scrollPaneWorkspaceInfo.
	 */
	private JScrollPane getScrollPaneWorkspaceInfo() {
		if (m_scrollPaneWorkspaceInfo == null) {

			m_scrollPaneWorkspaceInfo = new JScrollPane(
					getTextAreaWorkspaceInfo());
		}
		return m_scrollPaneWorkspaceInfo;
	}

	private JTextArea getTextAreaWorkspaceInfo() {
		if (m_textAreaWorkspaceInfo == null) {
			Font font = new Font("Serif", Font.PLAIN, 18);
			m_textAreaWorkspaceInfo = new JTextArea(8, 40);
			m_textAreaWorkspaceInfo.setFont(font);
			m_textAreaWorkspaceInfo.setEditable(false);
		}
		return m_textAreaWorkspaceInfo;
	}

	/**
	 * 获取m_panelWorkspaceOpen
	 * Get the m_panelWorkspaceOpen.
	 */
	private JPanel getPanelWorkspaceOpen() {
		if (m_panelWorkspaceOpen == null) {
			m_panelWorkspaceOpen = new WorkspaceConnectionInfoPanel(
					m_sampleRun, getTextAreaWorkspaceInfo());
			m_panelWorkspaceOpen.setName(getText("m_panelWorkspaceOpen1"));

			// 为打开面板添加所需的箱子
			// Add boxes to the Open panel.
			addBoxesToBaseBox(15, m_panelWorkspaceOpen.getVBoxWorkspaceInfo(),
					m_panelWorkspaceOpen.getVBoxServer(), m_panelWorkspaceOpen
							.getVBoxDatabase(), m_panelWorkspaceOpen
							.getVBoxUserName(), m_panelWorkspaceOpen
							.getVBoxPassword(), m_panelWorkspaceOpen
							.getVBoxWorkspaceName(), m_panelWorkspaceOpen
							.getVBoxButtonConfirm());

			// 初始化时文件型的数据库名，用户名和工作空间名不可见
			// Set the database name,username and the workspace name is not visible.
			m_panelWorkspaceOpen.getLabelWorkspaceInfoServer().setText(getText("m_panelWorkspaceOpen2"));
			m_panelWorkspaceOpen.getVBoxDatabase().setVisible(false);
			m_panelWorkspaceOpen.getVBoxUserName().setVisible(false);
			m_panelWorkspaceOpen.getVBoxWorkspaceName().setVisible(false);
			final JList list = m_panelWorkspaceOpen.getListWorkspaceType();
			list.addListSelectionListener(new ListSelectionListener() {
				public void valueChanged(ListSelectionEvent e) {
					m_selectedIndex = list.getSelectedIndex();
					if (list.getSelectedIndex() == 0) {
						m_panelWorkspaceOpen.getVBoxWorkspaceName().setVisible(
								false);
					} else {
						m_panelWorkspaceOpen.getVBoxWorkspaceName().setVisible(
								true);
					}
				}
			});
		}
		return m_panelWorkspaceOpen;
	}

	/**
	 * 获取m_panelWorkspaceSaveAs
	 * Get the m_panelWorkspaceSaveAs.
	 */
	private JPanel getPanelWorkspaceSaveAs() {
		if (m_panelWorkspaceSaveAs == null) {
			m_panelWorkspaceSaveAs = new WorkspaceConnectionInfoPanel(
					m_sampleRun, getTextAreaWorkspaceInfo());
			m_panelWorkspaceSaveAs.setName(getText("m_panelWorkspaceSaveAs"));

			// 为另存面板添加所需的箱子
			// Add boxes to the SaveAs panel.
			addBoxesToBaseBox(6, m_panelWorkspaceSaveAs.getVBoxWorkspaceInfo(),
					m_panelWorkspaceSaveAs.getVBoxServer(),
					m_panelWorkspaceSaveAs.getVBoxDatabase(),
					m_panelWorkspaceSaveAs.getVBoxUserName(),
					m_panelWorkspaceSaveAs.getVBoxPassword(),
					m_panelWorkspaceSaveAs.getVBoxWorkspaceVersion(),
					m_panelWorkspaceSaveAs.getVBoxWorkspaceType(),
					m_panelWorkspaceSaveAs.getVBoxWorkspaceName(),
					m_panelWorkspaceSaveAs.getVBoxButtonConfirm());

			// 初始化时文件型的数据库名，用户名不可见
			// Set the database name,and username is not visible.
			m_panelWorkspaceSaveAs.getVBoxDatabase().setVisible(false);
			m_panelWorkspaceSaveAs.getVBoxUserName().setVisible(false);
			final JList list = m_panelWorkspaceSaveAs.getListWorkspaceType();
			list.addListSelectionListener(new ListSelectionListener() {
				public void valueChanged(ListSelectionEvent e) {
					m_selectedIndex = list.getSelectedIndex();
				}
			});
		}
		return m_panelWorkspaceSaveAs;
	}

	/**
	 * 获取m_panelWorkspaceCreate
	 * Get the m_panelWorkspaceCreate.
	 */
	private JPanel getPanelWorkspaceCreate() {
		if (m_panelWorkspaceCreate == null) {
			m_panelWorkspaceCreate = new WorkspaceConnectionInfoPanel(
					m_sampleRun, getTextAreaWorkspaceInfo());
			m_panelWorkspaceCreate.setName(getText("m_panelWorkspaceCreate"));

			// 为创建面板添加所需的箱子
			// Add boxes to the Create panel.
			addBoxesToBaseBox(6, m_panelWorkspaceCreate.getVBoxWorkspaceInfo(),
					m_panelWorkspaceCreate.getVBoxServer(),
					m_panelWorkspaceCreate.getVBoxDatabase(),
					m_panelWorkspaceCreate.getVBoxUserName(),
					m_panelWorkspaceCreate.getVBoxPassword(),
					m_panelWorkspaceCreate.getVBoxWorkspaceVersion(),
					m_panelWorkspaceCreate.getVBoxWorkspaceType(),
					m_panelWorkspaceCreate.getVBoxWorkspaceName(),
					m_panelWorkspaceCreate.getVBoxButtonConfirm());

			// 初始化时文件型的数据库名，用户名不可见
			// Set the database name,and username is not visible.
			m_panelWorkspaceCreate.getVBoxDatabase().setVisible(false);
			m_panelWorkspaceCreate.getVBoxUserName().setVisible(false);
			final JList list = m_panelWorkspaceCreate.getListWorkspaceType();
			list.addListSelectionListener(new ListSelectionListener() {
				public void valueChanged(ListSelectionEvent e) {
					m_selectedIndex = list.getSelectedIndex();
				}
			});
		}
		return m_panelWorkspaceCreate;
	}

	/**
	 * 获取m_panelWorkspaceDelete
	 * Get the m_panelWorkspaceDelete.
	 */
	private JPanel getPanelWorkspaceDelete() {
		if (m_panelWorkspaceDelete == null) {
			m_panelWorkspaceDelete = new WorkspaceConnectionInfoPanel(
					m_sampleRun, getTextAreaWorkspaceInfo());
			m_panelWorkspaceDelete.setName(getText("m_panelWorkspaceDelete"));

			// 为删除面板添加所需的箱子
			// Add boxes to the Delete panel.
			addBoxesToBaseBox(8, m_panelWorkspaceDelete.getVBoxWorkspaceInfo(),
					m_panelWorkspaceDelete.getVBoxServer(),
					m_panelWorkspaceDelete.getVBoxDatabase(),
					m_panelWorkspaceDelete.getVBoxUserName(),
					m_panelWorkspaceDelete.getVBoxPassword(),
					m_panelWorkspaceDelete.getVBoxWorkspaceName(),
					m_panelWorkspaceDelete.getVBoxButtonConfirm());

			// 初始化时文件型的数据库名，用户名和工作空间名不可见
			// Set the database name,username and the workspace name is not visible.
			m_panelWorkspaceDelete.getVBoxDatabase().setVisible(false);
			m_panelWorkspaceDelete.getVBoxUserName().setVisible(false);
			m_panelWorkspaceDelete.getVBoxWorkspaceName().setVisible(false);
			final JList list = m_panelWorkspaceDelete.getListWorkspaceType();
			list.addListSelectionListener(new ListSelectionListener() {
				public void valueChanged(ListSelectionEvent e) {
					m_selectedIndex = list.getSelectedIndex();
					if (list.getSelectedIndex() == 0) {
						m_panelWorkspaceDelete.getVBoxWorkspaceName()
								.setVisible(false);
					} else {
						m_panelWorkspaceDelete.getVBoxWorkspaceName()
								.setVisible(true);
					}
				}
			});
		}
		return m_panelWorkspaceDelete;
	}

	/**
	 * 向整体垂直箱子中添加每行组件的垂直箱子
	 * Add vertical boxes.
	 */
	private void addBoxesToBaseBox(int value, Box baseBox, Box... boxes) {
		for (Box box : boxes) {
			box.add(Box.createVerticalStrut(value));
			baseBox.add(box);
		}
	}
	
	// 根据语言设置text是中文还是英文
	// To change text to English or Chinede by CurrentCulture
	private String getText(String id)
	{
		String text = "";
		if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{ 
			if(id == "m_tabbedPaneWorkspaceManage1")
			{
				text = "打开工作空间";
			} 
			if(id == "m_tabbedPaneWorkspaceManage2")
			{
				text = "另存工作空间";
			} 
			if(id == "m_tabbedPaneWorkspaceManage3")
			{
				text = "创建工作空间";
			} 
			if(id == "m_tabbedPaneWorkspaceManage4")
			{
				text = "删除工作空间";
			} 
			if(id == "m_panelWorkspaceOpen1")
			{
				text = "打开";
			} 
			if(id == "m_panelWorkspaceOpen2")
			{
				text = "文件路径";
			} 
			if(id == "m_panelWorkspaceSaveAs")
			{
				text = "另存";
			} 
			if(id == "m_panelWorkspaceCreate")
			{
				text = "创建";
			} 
			if(id == "m_panelWorkspaceDelete")
			{
				text = "删除";
			}
		}
		else
		{
			if(id == "m_tabbedPaneWorkspaceManage1")
			{
				text = "Open the workspace.";
			} 
			if(id == "m_tabbedPaneWorkspaceManage2")
			{
				text ="Save the current workspace as another workspace."; 
			} 
			if(id == "m_tabbedPaneWorkspaceManage3")
			{
				text = "Create the workspace.";
			} 
			if(id == "m_tabbedPaneWorkspaceManage4")
			{
				text = "Delete the workspace.";
			} 
			if(id == "m_panelWorkspaceOpen1")
			{
				text = "Open";
			} 
			if(id == "m_panelWorkspaceOpen2")
			{
				text = "Path";
			} 
			if(id == "m_panelWorkspaceSaveAs")
			{
				text = "SaveAs";
			} 
			if(id == "m_panelWorkspaceCreate")
			{
				text = "Create";
			} 
			if(id == "m_panelWorkspaceDelete")
			{
				text = "Delete";
			}
		}
		return text;
	}
	
}

/**
 * 内部类，用于初始化面板
 * Internal class for initializing the panel.
 */
class WorkspaceConnectionInfoPanel extends JPanel {

	private static final long serialVersionUID = 1L;

	private SampleRun m_sampleRun;

	private JTextArea m_textAreaWorkspaceInfo;

	private JPanel m_panelWorkspaceConnectionInfo;

	private JScrollPane m_scrollPaneWorkspaceType;

	private JList m_listWorkspaceType;

	private DefaultListModel m_listModelWorkspaceType;

	private JLabel m_labelWorkspaceInfoServer;

	private JLabel m_labelDatabase;

	private JLabel m_labelUserName;

	private JLabel m_labelPassword;

	private JLabel m_labelWorkspaceName;

	private JLabel m_labelWorkspaceVersion;

	private JLabel m_labelWorkspaceType;

	private JTextField m_textFieldServer;

	private JTextField m_textFieldDatabase;

	private JTextField m_textFieldUserName;

	private JPasswordField m_textFieldPassword;

	private JTextField m_textFieldWorkspaceName;

	private JComboBox m_comboBoxWorkspaceVersion;

	private JComboBox m_comboBoxWorkspaceType;

	private JButton m_buttonBrowse;

	private JButton m_buttonConfirm;

	private Box m_vBoxServer;

	private Box m_vBoxDatabase;

	private Box m_vBoxUserName;

	private Box m_vBoxPassword;

	private Box m_vBoxWorkspaceName;

	private Box m_vBoxWorkspaceVersion;

	private Box m_vBoxWorkspaceType;

	private Box m_vBoxWorkspaceInfo;

	private Box m_vBoxConfirm;

	/**
	 * 面板构造函数
	 * The panel constructor.
	 */
	public WorkspaceConnectionInfoPanel(SampleRun sampleRun,
			JTextArea textAreaWorkspaceInfo) {
		super();
		m_sampleRun = sampleRun;
		m_textAreaWorkspaceInfo = textAreaWorkspaceInfo;
		m_labelWorkspaceInfoServer = new JLabel();
		initialize();
	}

	/**
	 * 面板初始化
	 * The panel initialization.
	 */
	public void initialize() {
		this.setSize(300, 240);
		this.setLayout(new BorderLayout());
		this.add(this.getScrollPaneWorkspaceType(), BorderLayout.WEST);
		this.add(this.getPanelWorkspaceConnectionInfo(), BorderLayout.CENTER);
	}

	/**
	 * 获取m_scrollPaneWorkspaceType
	 * Get the m_scrollPaneWorkspaceType.
	 */
	public JScrollPane getScrollPaneWorkspaceType() {
		if (m_scrollPaneWorkspaceType == null) {
			m_scrollPaneWorkspaceType = new JScrollPane();
			m_scrollPaneWorkspaceType.setViewportView(getListWorkspaceType());
		}
		return m_scrollPaneWorkspaceType;
	}

	/**
	 * 获取m_listWorkspaceType
	 * Get the m_listWorkspaceType.
	 */
	public JList getListWorkspaceType() {
		if (m_listWorkspaceType == null) {
			m_listModelWorkspaceType = new DefaultListModel();
			// 添加三种类型的工作空间
			// Add 3 types workspace.
			m_listModelWorkspaceType.addElement(getText("m_listModelWorkspaceType1"));
			m_listModelWorkspaceType.addElement(getText("m_listModelWorkspaceType2"));
			m_listModelWorkspaceType.addElement(getText("m_listModelWorkspaceType3"));
			m_listWorkspaceType = new JList(m_listModelWorkspaceType);
			m_listWorkspaceType
					.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

			// 默认都选择文件型
			// Default type is file type.
			m_listWorkspaceType
					.addListSelectionListener(new ListSelectionListener() {
						public void valueChanged(ListSelectionEvent e) {
							// 切换时将每个文本域都清空
							// Clear the text when switching.
							getTextFieldServer().setText("");
							getTextFieldDatabase().setText("");
							getTextFieldUserName().setText("");
							getTextFieldPassword().setText("");
							getTextFieldWorkspaceName().setText("");
							getComboBoxWorkspaceVersion().setSelectedIndex(0);
							getComboBoxWorkspaceType().setSelectedIndex(0);
							if (m_listWorkspaceType.getSelectedIndex() == 0) {
								m_labelWorkspaceInfoServer.setText(getText("m_labelWorkspaceInfoServer1"));
								// 数据库名和用户名文件型工作空间不需要
								// Set the database name and username is not visible.
								getVBoxDatabase().setVisible(false);
								getVBoxUserName().setVisible(false);

								// 设置选择文件按钮和选择工作空间类型下拉菜单在文件型工作空间时可用
								// Set the file selection button and workspace selection menu is useable.
								getButtonBrowse().setVisible(true);
								getComboBoxWorkspaceType().setEnabled(true);
							} else {
								m_labelWorkspaceInfoServer.setText(getText("m_labelWorkspaceInfoServer2"));
								getVBoxDatabase().setVisible(true);
								getVBoxUserName().setVisible(true);
								getButtonBrowse().setVisible(false);
								getComboBoxWorkspaceType().setEnabled(false);
							}
						}
					});
		}
		return m_listWorkspaceType;
	}

	/**
	 * 获取m_textFieldServer
	 * Get the m_textFieldServer.
	 */
	public JTextField getTextFieldServer() {
		if (m_textFieldServer == null) {
			m_textFieldServer = new JTextField(15);
			m_textFieldServer.setMaximumSize(m_textFieldServer
					.getPreferredSize());
		}
		return m_textFieldServer;
	}

	/**
	 * 获取m_textFieldDatabase
	 * Get the m_textFieldDatabase.
	 */
	public JTextField getTextFieldDatabase() {
		if (m_textFieldDatabase == null) {
			m_textFieldDatabase = new JTextField();
		}
		return m_textFieldDatabase;
	}

	/**
	 * 获取m_textFieldUserName
	 * Get the m_textFieldUserName.
	 */
	public JTextField getTextFieldUserName() {
		if (m_textFieldUserName == null) {
			m_textFieldUserName = new JTextField();
		}
		return m_textFieldUserName;
	}

	/**
	 * 获取m_textFieldPassword
	 * Get the m_textFieldPassword.
	 */
	public JPasswordField getTextFieldPassword() {
		if (m_textFieldPassword == null) {
			m_textFieldPassword = new JPasswordField();
		}
		return m_textFieldPassword;
	}

	/**
	 * 获取m_textFieldWorkspaceName
	 * Get the m_textFieldWorkspaceName.
	 */
	public JTextField getTextFieldWorkspaceName() {
		if (m_textFieldWorkspaceName == null) {
			m_textFieldWorkspaceName = new JTextField();
		}
		return m_textFieldWorkspaceName;
	}

	/**
	 * 获取m_buttonBrowseSaveAs
	 * Get the m_buttonBrowseSaveAs.
	 */
	public JButton getButtonBrowse() {
		if (m_buttonBrowse == null) {
			m_buttonBrowse = new JButton();
			m_buttonBrowse.setText(getText("m_buttonBrowse"));
			m_buttonBrowse.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					JButton button = (JButton) e.getSource();
					JPanel panel = (JPanel) button.getParent().getParent()
							.getParent().getParent().getParent();
					if (panel.getName().equals(getText("m_delete"))
							|| panel.getName().equals(getText("m_open"))) {
						m_sampleRun
								.browseWorkspaceSXW(panel, m_textFieldServer);
					} else {
						m_sampleRun.browseWorkspaceSXWSaveAs(
								WorkspaceConnectionInfoPanel.this,
								m_textFieldServer);
					}
				}
			});
		}
		return m_buttonBrowse;
	}

	/**
	 * 获取m_comboBoxWorkspaceType
	 * Get the m_comboBoxWorkspaceType.
	 */
	public JComboBox getComboBoxWorkspaceType() {
		if (m_comboBoxWorkspaceType == null) {
			m_comboBoxWorkspaceType = new JComboBox();
			m_comboBoxWorkspaceType.addItem("*.sxw");
			m_comboBoxWorkspaceType.addItem("*.smw");
			m_comboBoxWorkspaceType.addItem("*.sxwu");
			m_comboBoxWorkspaceType.addItem("*.smwu");
		}
		return m_comboBoxWorkspaceType;
	}

	/**
	 * 获取m_panelWorkspaceConnectionInfo
	 * Get the m_panelWorkspaceConnectionInfo.
	 */
	public JPanel getPanelWorkspaceConnectionInfo() {
		if (m_panelWorkspaceConnectionInfo == null) {
			m_panelWorkspaceConnectionInfo = new JPanel();
			m_panelWorkspaceConnectionInfo.add(getVBoxWorkspaceInfo());
			m_panelWorkspaceConnectionInfo
					.setSize(m_panelWorkspaceConnectionInfo.getPreferredSize());
			getListWorkspaceType().setSelectedIndex(0);
		}
		return m_panelWorkspaceConnectionInfo;
	}

	/**
	 * 获取m_buttonConfirm
	 * Get the m_buttonConfirm.
	 */
	public JButton getButtonConfirm() {
		if (m_buttonConfirm == null) {
			m_buttonConfirm = new JButton();
			m_buttonConfirm.setText(getText("m_buttonConfirm"));
			m_buttonConfirm.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					m_textAreaWorkspaceInfo.setText("");
					// 触发事件按钮所处的面板
					// The event panel.
					JButton button = (JButton) e.getSource();
					JPanel panel = (JPanel) button.getParent().getParent()
							.getParent().getParent().getParent();
					if (panel.getName().equals(getText("m_open"))) {
						if (m_listWorkspaceType.getSelectedIndex() == 0) {
							m_sampleRun.openWorkspaceSXW(m_textFieldServer,
									m_textFieldPassword,
									m_textAreaWorkspaceInfo);
						} else {
							m_sampleRun.openWorkspaceSQL(m_textFieldServer,
									m_textFieldDatabase, m_textFieldUserName,
									m_textFieldPassword,
									m_textFieldWorkspaceName,
									m_textAreaWorkspaceInfo,
									m_listWorkspaceType.getSelectedIndex());
						}
					}
					if (panel.getName().equals(getText("m_saveas"))) {
						if (m_listWorkspaceType.getSelectedIndex() == 0) {
							m_sampleRun.workspaceSaveAsSXW(m_textFieldServer,
									m_textFieldWorkspaceName,
									m_textFieldPassword,
									m_comboBoxWorkspaceVersion,
									m_comboBoxWorkspaceType,
									m_textAreaWorkspaceInfo);
						} else {
							m_sampleRun.workspaceSaveAsSQL(m_textFieldServer,
									m_textFieldDatabase, m_textFieldUserName,
									m_textFieldPassword,
									m_textFieldWorkspaceName,
									m_comboBoxWorkspaceVersion,
									m_textAreaWorkspaceInfo,
									m_listWorkspaceType.getSelectedIndex());
						}
					}
					if (panel.getName().equals(getText("m_create"))) {
						if (m_listWorkspaceType.getSelectedIndex() == 0) {
							m_sampleRun.createWorkspaceSXW(m_textFieldServer,
									m_textFieldWorkspaceName,
									m_textFieldPassword,
									m_comboBoxWorkspaceVersion,
									m_comboBoxWorkspaceType,
									m_textAreaWorkspaceInfo);
						} else {
							m_sampleRun.createWorkspaceSQL(m_textFieldServer,
									m_textFieldDatabase, m_textFieldUserName,
									m_textFieldPassword,
									m_textFieldWorkspaceName,
									m_comboBoxWorkspaceVersion,
									m_textAreaWorkspaceInfo,
									m_listWorkspaceType.getSelectedIndex());
						}
					}
					if (panel.getName().equals(getText("m_delete"))) {
						if (m_listWorkspaceType.getSelectedIndex() == 0) {
							m_sampleRun.deleteWorkspaceSXW(m_textFieldServer,
									m_textFieldPassword,
									m_comboBoxWorkspaceType,
									m_textAreaWorkspaceInfo);
						} else {
							m_sampleRun.deleteWorkspaceSQL(m_textFieldServer,
									m_textFieldDatabase, m_textFieldUserName,
									m_textFieldPassword,
									m_textFieldWorkspaceName,
									m_textAreaWorkspaceInfo,
									m_listWorkspaceType.getSelectedIndex());
						}
					}
				}
			});
		}
		return m_buttonConfirm;
	}

	/**
	 * 获取m_comboBoxWorkspaceVersion
	 * Get the m_comboBoxWorkspaceVersion.
	 */
	public JComboBox getComboBoxWorkspaceVersion() {
		if (m_comboBoxWorkspaceVersion == null) {
			m_comboBoxWorkspaceVersion = new JComboBox();
			m_comboBoxWorkspaceVersion.addItem("ugc60");
			m_comboBoxWorkspaceVersion.addItem("ugc20");
			m_comboBoxWorkspaceVersion.addItem("sfc60");
		}
		return m_comboBoxWorkspaceVersion;
	}

	/**
	 * Get the m_labelWorkspaceInfoServer
	 */
	public JLabel getLabelWorkspaceInfoServer() {
		if (m_labelWorkspaceInfoServer == null) {
			m_labelWorkspaceInfoServer = new JLabel();
			m_labelWorkspaceInfoServer.setText(getText("m_labelWorkspaceInfoServer2"));
		}
		return m_labelWorkspaceInfoServer;
	}

	/**
	 * 获取m_labelDatabase
	 * Get the m_labelDatabase.
	 */
	public JLabel getLabelDatabase() {
		if (m_labelDatabase == null) {
			m_labelDatabase = new JLabel();
			m_labelDatabase.setText(getText("m_labelDatabase"));
		}
		return m_labelDatabase;
	}

	/**
	 * 获取m_labelUserName
	 * Get the m_labelUserName.
	 */
	public JLabel getLabelUserName() {
		if (m_labelUserName == null) {
			m_labelUserName = new JLabel();
			m_labelUserName.setText(getText("m_labelUserName"));
		}
		return m_labelUserName;
	}

	/**
	 * 获取m_labelPassword
	 * Get the m_labelPassword.
	 */
	public JLabel getLabelPassword() {
		if (m_labelPassword == null) {
			m_labelPassword = new JLabel();
			m_labelPassword.setText(getText("m_labelPassword"));
		}
		return m_labelPassword;
	}

	/**
	 * 获取m_labelWorkspaceName
	 * Get the m_labelWorkspaceName.
	 */
	public JLabel getLabelWorkspaceName() {
		if (m_labelWorkspaceName == null) {
			m_labelWorkspaceName = new JLabel();
			m_labelWorkspaceName.setText(getText("m_labelWorkspaceName"));
		}
		return m_labelWorkspaceName;
	}

	/**
	 * 获取m_labelWorkspaceVersion
	 * Get the m_labelWorkspaceVersion.
	 */
	public JLabel getLabelWorkspaceVersion() {
		if (m_labelWorkspaceVersion == null) {
			m_labelWorkspaceVersion = new JLabel();
			m_labelWorkspaceVersion.setText(getText("m_labelWorkspaceVersion"));
		}
		return m_labelWorkspaceVersion;
	}

	/**
	 * 获取m_labelWorkspaceType
	 * Get the m_labelWorkspaceType.
	 */
	public JLabel getLabelWorkspaceType() {
		if (m_labelWorkspaceType == null) {
			m_labelWorkspaceType = new JLabel();
			m_labelWorkspaceType.setText(getText("m_labelWorkspaceType"));
		}
		return m_labelWorkspaceType;
	}

	/**
	 * 获取m_vBoxServer
	 * Get the m_vBoxServer.
	 */
	public Box getVBoxServer() {
		if (m_vBoxServer == null) {
			Box hBoxServer = Box.createHorizontalBox();
			addToHBox(hBoxServer, 38, getLabelWorkspaceInfoServer(),
					getTextFieldServer(), getButtonBrowse());

			m_vBoxServer = Box.createVerticalBox();
			m_vBoxServer.add(hBoxServer);
		}
		return m_vBoxServer;
	}

	/**
	 * 获取m_vBoxDatabase
	 * Get the m_vBoxDatabase.
	 */
	public Box getVBoxDatabase() {
		if (m_vBoxDatabase == null) {
			Box hBoxDatabase = Box.createHorizontalBox();
			addToHBox(hBoxDatabase, 38, getLabelDatabase(),
					getTextFieldDatabase());

			m_vBoxDatabase = Box.createVerticalBox();
			m_vBoxDatabase.add(hBoxDatabase);
		}
		return m_vBoxDatabase;
	}

	/**
	 * 获取m_vBoxUserName
	 * Get the m_vBoxUserName.
	 */
	public Box getVBoxUserName() {
		if (m_vBoxUserName == null) {
			Box hBoxUserName = Box.createHorizontalBox();
			addToHBox(hBoxUserName, 51, getLabelUserName(),
					getTextFieldUserName());

			m_vBoxUserName = Box.createVerticalBox();
			m_vBoxUserName.add(hBoxUserName);
		}
		return m_vBoxUserName;
	}

	/**
	 * 获取m_vBoxPassword
	 * Get the m_vBoxPassword.
	 */
	public Box getVBoxPassword() {
		if (m_vBoxPassword == null) {
			Box hBoxPassword = Box.createHorizontalBox();
			addToHBox(hBoxPassword, 64, getLabelPassword(),
					getTextFieldPassword());

			m_vBoxPassword = Box.createVerticalBox();
			m_vBoxPassword.add(hBoxPassword);
		}
		return m_vBoxPassword;
	}

	/**
	 * 获取m_vBoxWorkspaceName
	 * Get the m_vBoxWorkspaceName.
	 */
	public Box getVBoxWorkspaceName() {
		if (m_vBoxWorkspaceName == null) {
			Box hBoxWorkspaceName = Box.createHorizontalBox();
			addToHBox(hBoxWorkspaceName, 25, getLabelWorkspaceName(),
					getTextFieldWorkspaceName());

			m_vBoxWorkspaceName = Box.createVerticalBox();
			m_vBoxWorkspaceName.add(hBoxWorkspaceName);
		}
		return m_vBoxWorkspaceName;
	}

	/**
	 * 获取m_vBoxWorkspaceVersion
	 * Get the m_vBoxWorkspaceVersion.
	 */
	public Box getVBoxWorkspaceVersion() {
		if (m_vBoxWorkspaceVersion == null) {
			Box hBoxWorkspaceVersion = Box.createHorizontalBox();
			addToHBox(hBoxWorkspaceVersion, 12, getLabelWorkspaceVersion(),
					getComboBoxWorkspaceVersion());

			m_vBoxWorkspaceVersion = Box.createVerticalBox();
			m_vBoxWorkspaceVersion.add(hBoxWorkspaceVersion);
		}
		return m_vBoxWorkspaceVersion;
	}

	/**
	 * 获取m_vBoxWorkspaceType
	 * Get the m_vBoxWorkspaceType.
	 */
	public Box getVBoxWorkspaceType() {
		if (m_vBoxWorkspaceType == null) {
			Box hBoxWorkspaceType = Box.createHorizontalBox();
			addToHBox(hBoxWorkspaceType, 12, getLabelWorkspaceType(),
					getComboBoxWorkspaceType());

			m_vBoxWorkspaceType = Box.createVerticalBox();
			m_vBoxWorkspaceType.add(hBoxWorkspaceType);
		}
		return m_vBoxWorkspaceType;
	}

	/**
	 * 获取m_vBoxConfirm
	 * Get the m_vBoxConfirm.
	 */
	public Box getVBoxButtonConfirm() {
		if (m_vBoxConfirm == null) {
			Box hBoxConfirm = Box.createHorizontalBox();
			hBoxConfirm.add(Box.createGlue());
			hBoxConfirm.add(getButtonConfirm());

			m_vBoxConfirm = Box.createVerticalBox();
			m_vBoxConfirm.add(hBoxConfirm);
		}
		return m_vBoxConfirm;
	}

	/**
	 * 获取存放所有工作空间信息组件的垂直箱子
	 * Get the all vertical boxes.
	 */
	public Box getVBoxWorkspaceInfo() {
		if (m_vBoxWorkspaceInfo == null) {
			m_vBoxWorkspaceInfo = Box.createVerticalBox();
			m_vBoxWorkspaceInfo.add(Box.createVerticalStrut(8));
		}
		return m_vBoxWorkspaceInfo;
	}

	/**
	 * 向水平箱子中添加组件
	 * Add components to horizontal boxes.
	 */
	private void addToHBox(Box hBox, int value, JLabel label,
			Component... components) {
		hBox.add(label);
		hBox.add(Box.createHorizontalStrut(value));
		for (Component component : components) {
			hBox.add(component);
		}
	}
	// 根据语言设置text是中文还是英文
	// To change text to English or Chinede by CurrentCulture
	private String getText(String id)
	{
		String text = "";
		if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if(id == "m_listModelWorkspaceType1")
			{
				text = "文件型工作空间";
			} 
			if(id == "m_listModelWorkspaceType2")
			{
				text = "Oracle工作空间";
			}
			if(id == "m_listModelWorkspaceType3")
			{
				text = "SQL工作空间";
			}
			if(id == "m_labelWorkspaceInfoServer1")
			{
				text = "文件路径";
			}
			if(id == "m_labelWorkspaceInfoServer2")
			{
				text = "服务器名";
			}
			if(id == "m_buttonBrowse")
			{
				text = "浏览";
			}
			if(id == "m_delete")
			{
				text = "删除";
			}
			if(id == "m_open")
			{
				text = "打开";
			}
			if(id == "m_buttonConfirm")
			{
				text = "确定";
			}
			if(id == "m_saveas")
			{
				text = "另存";
			}
			if(id == "m_create")
			{
				text = "创建";
			}
			if(id == "m_labelDatabase")
			{
				text = "数据库名";
			}
			if(id == "m_labelUserName")
			{
				text = "用户名";
			}
			if(id == "m_labelPassword")
			{
				text = "密码";
			}
			if(id == "m_labelWorkspaceName")
			{
				text = "工作空间名";
			}
			if(id == "m_labelWorkspaceVersion")
			{
				text = "工作空间版本";
			}
			if(id == "m_labelWorkspaceType")
			{
				text = "工作空间类型";
			}
		}
		else
		{
			if(id == "m_listModelWorkspaceType1")
			{
				text = "File type workspace.";
			} 
			if(id == "m_listModelWorkspaceType2")
			{
				text = "Oracle workspace.";
			}
			if(id == "m_listModelWorkspaceType3")
			{
				text = "SQL workspace.";
			}
			if(id == "m_labelWorkspaceInfoServer1")
			{
				text = "Path";
			}
			if(id == "m_labelWorkspaceInfoServer2")
			{
				text = "Server name";
			}
			if(id == "m_buttonBrowse")
			{
				text = "Browse";
			}
			if(id == "m_delete")
			{
				text = "Delete";
			}
			if(id == "m_open")
			{
				text = "Open";
			}
			if(id == "m_buttonConfirm")
			{
				text = "Yes";
			}
			if(id == "m_saveas")
			{
				text = "SaveAs";
			}
			if(id == "m_create")
			{
				text = "Create";
			}
			if(id == "m_labelDatabase")
			{
				text = "Database name";
			}
			if(id == "m_labelUserName")
			{
				text = "User name";
			}
			if(id == "m_labelPassword")
			{
				text = "Password";
			}
			if(id == "m_labelWorkspaceName")
			{
				text = "Workspace name";
			}
			if(id == "m_labelWorkspaceVersion")
			{
				text = "Workspace version";
			}
			if(id == "m_labelWorkspaceType")
			{
				text = "Workspace Type";
			}
		}
		return text;
	}
}

